pybedtools.contrib.MultiClassifier
==================================

.. currentmodule:: pybedtools.contrib

.. autoclass:: MultiClassifier

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MultiClassifier.__init__
      ~MultiClassifier.classify
      ~MultiClassifier.hierarchical_table
      ~MultiClassifier.print_table
      ~MultiClassifier.split_annotations
      ~MultiClassifier.table
   
   

   
   
   